<?php
/**
 * Registering meta boxes
 *
 * All the definitions of meta boxes are listed below with comments.
 *
 * For more information, please visit:
 * @link http://www.deluxeblogtips.com/meta-box/
 */


/**
 * Enqueue script for handling actions with meta boxes
 *
 * @since 1.0
 *
 * @param string $hook
 */
function baroque_meta_box_scripts( $hook ) {
	// Detect to load un-minify scripts when WP_DEBUG is enable
	$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	if ( in_array( $hook, array( 'post.php', 'post-new.php' ) ) ) {
		wp_enqueue_script( 'baroque-meta-boxes', get_template_directory_uri() . "/js/backend/meta-boxes$min.js", array( 'jquery' ), '20161025', true );
	}
}

add_action( 'admin_enqueue_scripts', 'baroque_meta_box_scripts' );

/**
 * Registering meta boxes
 *
 * Using Meta Box plugin: http://www.deluxeblogtips.com/meta-box/
 *
 * @see http://www.deluxeblogtips.com/meta-box/docs/define-meta-boxes
 *
 * @param array $meta_boxes Default meta boxes. By default, there are no meta boxes.
 *
 * @return array All registered meta boxes
 */
function baroque_register_meta_boxes( $meta_boxes ) {
	// Post format's meta box
	$meta_boxes[] = array(
		'id'       => 'post-format-settings',
		'title'    => esc_html__( 'Format Details', 'baroque' ),
		'pages'    => array( 'post' ),
		'context'  => 'normal',
		'priority' => 'high',
		'autosave' => true,
		'fields'   => array(
			array(
				'name'             => esc_html__( 'Image', 'baroque' ),
				'id'               => 'image',
				'type'             => 'image_advanced',
				'class'            => 'image',
				'max_file_uploads' => 1,
			),
			array(
				'name'  => esc_html__( 'Gallery', 'baroque' ),
				'id'    => 'images',
				'type'  => 'image_advanced',
				'class' => 'gallery',
			),
			array(
				'name'  => esc_html__( 'Video', 'baroque' ),
				'id'    => 'video',
				'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'video',
			),
		),
	);

	// Header Video
	$meta_boxes[] = array(
		'id'       => 'header-video',
		'title'    => esc_html__( 'Header Banner', 'baroque' ),
		'pages'    => array( 'page' ),
		'context'  => 'normal',
		'priority' => 'high',
		'fields'   => array(
			array(
				'name' => esc_html__( 'Show Header Banner', 'baroque' ),
				'id'   => 'header_banner',
				'type' => 'checkbox',
				'std'  => false,
			),
			array(
				'name'    => esc_html__( 'Background Type', 'baroque' ),
				'id'      => 'background_type',
				'type'    => 'select',
				'options' => array(
					'image'     => esc_html__( 'Image', 'baroque' ),
					'video'     => esc_html__( 'Video', 'baroque' ),
					'revslider' => esc_html__( 'Revolution Sliders', 'baroque' ),
				),
			),
			array(
				'name'             => esc_html__( 'Background Image', 'baroque' ),
				'id'               => 'background_image',
				'type'             => 'image_advanced',
				'class'            => 'background_image',
				'max_file_uploads' => 1,
			),
			array(
				'name'              => esc_html__( 'Video file URL', 'baroque' ),
				'label_description' => esc_html__( 'Support Youtube and Vimeo only', 'baroque' ),
				'id'                => 'video_url',
				'type'              => 'textarea',
				'cols'              => 20,
				'rows'              => 2,
				'class'             => 'video_url',
			),
			array(
				'name'  => esc_html__( 'Banner Shortcode', 'baroque' ),
				'id'    => 'shortcode',
				'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'shortcode',
			),
			array(
				'name'  => esc_html__( 'Height', 'baroque' ),
				'id'    => 'height',
				'type'  => 'text',
				'class' => 'height',
			),
			array(
				'name'    => esc_html__( 'Text Color', 'baroque' ),
				'id'      => 'text_color',
				'type'    => 'select',
				'options' => array(
					'light' => esc_html__( 'Light', 'baroque' ),
					'dark'  => esc_html__( 'Dark', 'baroque' ),
				),
			),
			array(
				'name'  => esc_html__( 'Title', 'baroque' ),
				'id'    => 'title',
				'type'  => 'textarea',
				'class' => 'title',
			),
			array(
				'name'  => esc_html__( 'Subtitle', 'baroque' ),
				'id'    => 'subtitle',
				'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'sub_title',
			),
		),
	);

	// Display Settings
	$meta_boxes[] = array(
		'id'       => 'display-settings',
		'title'    => esc_html__( 'Display Settings', 'baroque' ),
		'pages'    => array( 'post', 'page' ),
		'context'  => 'normal',
		'priority' => 'high',
		'fields'   => array(
			array(
				'name' => esc_html__( 'Layout', 'baroque' ),
				'id'   => 'heading_layout',
				'type' => 'heading',
			),
			array(
				'name' => esc_html__( 'Custom Layout', 'baroque' ),
				'id'   => 'custom_page_layout',
				'type' => 'checkbox',
				'std'  => false,
			),
			array(
				'name'    => esc_html__( 'Layout', 'baroque' ),
				'id'      => 'layout',
				'type'    => 'image_select',
				'class'   => 'custom-page-layout',
				'options' => array(
					'full-content'    => get_template_directory_uri() . '/img/sidebars/empty.png',
					'sidebar-content' => get_template_directory_uri() . '/img/sidebars/single-left.png',
					'content-sidebar' => get_template_directory_uri() . '/img/sidebars/single-right.png',
				),
			),
		),
	);

	// Footer Settings
	$meta_boxes[] = array(
		'id'       => 'footer-settings',
		'title'    => esc_html__( 'Footer Settings', 'baroque' ),
		'pages'    => array( 'page' ),
		'context'  => 'normal',
		'priority' => 'high',
		'fields'   => array(
			array(
				'name' => esc_html__( 'Hide Newsletter', 'baroque' ),
				'id'   => 'hide_newsletter',
				'type' => 'checkbox',
				'std'  => false,
			),
			array(
				'name' => esc_html__( 'Hide Footer', 'baroque' ),
				'id'   => 'hide_footer',
				'type' => 'checkbox',
				'std'  => false,
			),
			array(
				'name' => esc_html__( 'Custom Layout', 'baroque' ),
				'id'   => 'custom_footer_layout',
				'type' => 'checkbox',
				'std'  => false,
			),
			array(
				'name'    => esc_html__( 'Footer Layout', 'baroque' ),
				'id'      => 'footer_layout',
				'type'    => 'select',
				'options' => array(
					1 => esc_html__( 'Layout 1', 'baroque' ),
					2 => esc_html__( 'Layout 2', 'baroque' ),
					3 => esc_html__( 'Layout 3 ( Transparent )', 'baroque' ),
					4 => esc_html__( 'Layout 4', 'baroque' ),
				),
			),
		),
	);

	//Page Header Settings
	$meta_boxes[] = array(
		'id'       => 'page-header-settings',
		'title'    => esc_html__( 'Page Header Settings', 'baroque' ),
		'pages'    => array( 'page' ),
		'context'  => 'normal',
		'priority' => 'high',
		'fields'   => array(
			array(
				'name'  => esc_html__( 'Hide Page Header', 'baroque' ),
				'id'    => 'hide_page_header',
				'type'  => 'checkbox',
				'std'   => false,
				'class' => 'hide-homepage',
			),
			array(
				'name'  => esc_html__( 'Custom Title', 'baroque' ),
				'id'    => 'custom_title',
				'type'  => 'textarea',
				'std'   => false,
				'class' => 'hide-homepage',
			),
		),
	);

	// Portfolio Information
	$meta_boxes[] = array(
		'id'       => 'project-info',
		'title'    => esc_html__( 'Portfolio Info', 'baroque' ),
		'pages'    => array( 'portfolio' ),
		'context'  => 'normal',
		'priority' => 'high',
		'autosave' => true,
		'fields'   => array(
			array(
				'name'  => esc_html__( 'Gallery', 'baroque' ),
				'id'    => 'images',
				'type'  => 'image_advanced',
				'class' => 'gallery',
			),
			array(
				'name'  => esc_html__( 'Client', 'baroque' ),
				'id'    => 'client',
				'type'  => 'text',
				'class' => 'client',
			),
			array(
				'name'  => esc_html__( 'Location', 'baroque' ),
				'id'    => 'location',
				'type'  => 'text',
				'class' => 'location',
			),
			array(
				'name'  => esc_html__( 'Completion', 'baroque' ),
				'id'    => 'completion',
				'type'  => 'text',
				'class' => 'completion',
			),
			array(
				'name'  => esc_html__( 'Area', 'baroque' ),
				'id'    => 'area',
				'type'  => 'text',
				'class' => 'area',
			),
		),
	);

	// Portfolio Layout
	$meta_boxes[] = array(
		'id'       => 'project-layout',
		'title'    => esc_html__( 'Portfolio Setting Layout', 'baroque' ),
		'pages'    => array( 'portfolio' ),
		'context'  => 'normal',
		'priority' => 'high',
		'autosave' => true,
		'fields'   => array(
			array(
				'name' => esc_html__( 'Custom Layout', 'baroque' ),
				'id'   => 'custom_portfolio_layout',
				'type' => 'checkbox',
				'std'  => false,
			),
			array(
				'name'    => esc_html__( 'Layout', 'baroque' ),
				'id'      => 'portfolio_layout',
				'type'    => 'select',
				'options' => array(
					'1' => esc_html__( 'Layout 1', 'baroque' ),
					'2' => esc_html__( 'Layout 2', 'baroque' ),
					'3' => esc_html__( 'Layout 3', 'baroque' ),
					'4' => esc_html__( 'Layout 4', 'baroque' ),
				),
			),
		),
	);

	return $meta_boxes;
}

add_filter( 'rwmb_meta_boxes', 'baroque_register_meta_boxes' );

function baroque_admin_notice__success() {

	if ( ! function_exists('baroque_vc_addons_init') ) {
		return;
	}

	$versions = get_plugin_data( WP_PLUGIN_DIR . '/baroque-addons/baroque-addons.php' );
	if ( version_compare( $versions['Version'], '1.0.3', '>=' ) ) {
		return;
	}
	?>
	<div class="notice notice-info is-dismissible">
		<p>
			<strong><?php esc_html_e( 'The Baroque Addons plugin needs to be updated to 1.0.3 to ensure maximum compatibility with this theme. Go to Plugins > Baroque Addons to update it.', 'baroque' ); ?></strong>
		</p>
	</div>
	<?php
}

add_action( 'admin_notices', 'baroque_admin_notice__success' );