<?php
/**
 * Custom functions that act in the footer.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Baroque
 */

/**
 *  Display site footer
 */
function baroque_footer() {
	$f_layout  = baroque_get_option( 'footer_layout' );
	$p_layout  = baroque_get_option( 'single_portfolio_layout' );
	$p_style   = baroque_get_option( 'portfolio_style' );
	$mb_footer = intval(get_post_meta( get_the_ID(), 'hide_footer', true ));

	if ( get_post_meta( get_the_ID(), 'custom_portfolio_layout', true ) ) {
		$p_layout = get_post_meta( get_the_ID(), 'portfolio_layout', true );
	}

	if ( get_post_meta( get_the_ID(), 'custom_footer_layout', true ) ) {
		$f_layout = get_post_meta( get_the_ID(), 'footer_layout', true );
	}

	if (is_active_sidebar( 'footer-sidebar-1' ) == false &&
		is_active_sidebar( 'footer-sidebar-2' ) == false &&
		is_active_sidebar( 'footer-sidebar-3' ) == false &&
		is_active_sidebar( 'footer-sidebar-4' ) == false &&
		is_active_sidebar( 'footer-sidebar-5' ) == false &&
		is_active_sidebar( 'footer-sidebar-6' ) == false ) {
		return;
	}

	if ( $mb_footer ) {
		return;
	}

	if ( is_singular( 'portfolio' ) && $p_layout == '3' ) {
		return;
	}

	if ( baroque_is_portfolio() && $p_style == 'parallax' ) {
		return;
	}

	if ( is_page_template( 'template-coming-soon-page.php' ) ) {
		return;
	}

	$columns = max( 1, absint( baroque_get_option( 'footer_columns' ) ) );

	?>
	<div class="baroque-container">
		<div class="footer-layout-<?php echo esc_attr( $f_layout ); ?> columns-<?php echo esc_attr( $columns ) ?>">
			<div class="footer-content">
				<div class="footer-row">
					<?php ob_start(); ?>
					<?php for ( $i = 1; $i <= $columns; $i ++ ) : ?>

						<div class="footer-sidebar footer-<?php echo esc_attr( $i ) ?>">
							<?php dynamic_sidebar( "footer-sidebar-$i" ); ?>
						</div>

						<?php ; endfor; ?>
					<?php
					$output = ob_get_clean();
					echo apply_filters( 'baroque_footer_widget_content', $output )
					?>
				</div>
			</div>
		</div>
	</div>
	<?php
}

add_action( 'baroque_footer', 'baroque_footer' );

/**
 *  Display footer newsletter
 */
function baroque_footer_newsletter() {
	$newsletter = intval( baroque_get_option( 'footer_newsletter' ) );

	$mb_newsletter = intval(get_post_meta( get_the_ID(), 'hide_newsletter', true ));

	$p_layout = baroque_get_option( 'single_portfolio_layout' );
	$p_style  = baroque_get_option( 'portfolio_style' );

	if ( get_post_meta( get_the_ID(), 'custom_portfolio_layout', true ) ) {
		$p_layout = get_post_meta( get_the_ID(), 'portfolio_layout', true );
	}

	if ( ! $newsletter ) {
		return;
	}

	if ( $mb_newsletter ) {
		return;
	}

	if ( is_singular( 'portfolio' ) && $p_layout == '3' ) {
		return;
	}

	if ( baroque_is_portfolio() && $p_style == 'parallax' ) {
		return;
	}

	if ( is_page_template( 'template-coming-soon-page.php' ) ) {
		return;
	}

	?>
	<div class="footer-newsletter">
		<div class="container newsletter-content">
			<div class="row">
				<div class="col-md-5 col-sm-12 col-xs-12 newsletter-header">
					<h3><?php echo wp_kses( baroque_get_option( 'newsletter_title' ), wp_kses_allowed_html( 'post' ) ); ?></h3>
					<?php echo wp_kses( baroque_get_option( 'newsletter_desc' ), wp_kses_allowed_html( 'post' ) ); ?>
				</div>
				<div class="col-md-7 col-sm-12 col-xs-12 newsletter-form">
					<?php echo do_shortcode( wp_kses( baroque_get_option( 'newsletter_form' ), wp_kses_allowed_html( 'post' ) ) ); ?>
				</div>
			</div>
		</div>
	</div>
	<?php
}

add_action( 'baroque_before_footer', 'baroque_footer_newsletter', 10 );

/**
 * Add off mobile menu to footer
 *
 * @since 1.0.0
 */
function baroque_off_canvas_mobile_menu() {

	$menu_sidebar = baroque_get_option( 'header_menu_sidebar' );
	$h_layout = baroque_get_option( 'header_layout' );

	if ( ! $menu_sidebar ) {
		return;
	}

	$banner = baroque_get_option( 'canvas_menu_img' );
	$css = '';

	if ( $banner ) {
		$css = 'has-image';
	}
	
	?>
	<div class="menu-sidebar baroque-off-canvas-panel <?php echo esc_attr( $css ); ?>" id="menu-sidebar-panel">
		<div class="widget-panel-content">
			<div class="widget-panel-header">
				<a href="#" class="close-canvas-panel"><i class="icon-cross2"></i></a>
			</div>
			<div class="widget-panel-body">
				<div class="widget-panel-top">
					<?php
					$language_html = baroque_language_switcher();
					if ( in_array( 'language', $menu_sidebar ) && ! empty( $language_html ) ) {
						?>
						<div class="sidebar-language widget-language">
							<?php echo apply_filters( 'baroque_language_switcher_widget', $language_html ); ?>
						</div>
						<?php
					}
					?>

					<?php
					if ( in_array( 'menu', $menu_sidebar ) ) {
						?>
						<div class="sidebar-menu">
							<?php
							if ( has_nav_menu( 'primary' ) ) {
								wp_nav_menu(
									array(
										'theme_location' => 'primary',
										'container'      => false,
									)
								);
							}
							?>

							<?php
							if ( has_nav_menu( 'primary_2' ) && $h_layout == 'v5' && baroque_is_homepage() ) {

								echo '<div class="section-menu-secondary">';

								wp_nav_menu(
									array(
										'theme_location' => 'primary_2',
										'container'      => false,
									)
								);

								echo '</div>';
							}
							?>
						</div>
						<?php
					}
					?>
				</div>
				<div class="widget-panel-bottom">
					<?php
					if ( in_array( 'socials', $menu_sidebar ) ) {
						?>
						<div class="baroque-social-links-widget">
							<?php
							$header_social = baroque_get_option( 'menu_sidebar_socials' );

							baroque_get_socials_html( $header_social );
							?>
						</div>
						<?php
					}
					?>

					<?php
					if ( in_array( 'text', $menu_sidebar ) ) {
						?>
						<div class="sidebar-text">
							<?php echo do_shortcode( wp_kses( baroque_get_option( 'menu_sidebar_text' ), wp_kses_allowed_html( 'post' ) ) ); ?>
						</div>
						<?php
					}
					?>
				</div>
			</div>
		</div>
	</div>
	<?php
}

add_action( 'wp_footer', 'baroque_off_canvas_mobile_menu' );

/**
 * Display a layer to close canvas panel everywhere inside page
 *
 * @since 1.0.0
 */
function baroque_site_canvas_layer() {
	?>
	<div id="off-canvas-layer" class="off-canvas-layer"></div>
	<?php
}

add_action( 'wp_footer', 'baroque_site_canvas_layer' );

/**
 * Display back to top
 *
 * @since 1.0.0
 */
function baroque_back_to_top() {
	if ( intval( baroque_get_option( 'back_to_top' ) ) ) :
		$style = baroque_get_option( 'back_to_top_style' );

		?>
		<a id="scroll-top" class="backtotop style-<?php echo esc_attr( $style ) ?>" href="#">
			<i class="icon-arrow-up"></i>
		</a>
		<?php
	endif;
}

add_action( 'wp_footer', 'baroque_back_to_top' );

/**
 * Adds photoSwipe dialog element
 */
function baroque_gallery_images_lightbox() {

	if ( ! is_singular() ) {
		return;
	}

	?>
	<div id="pswp" class="pswp" tabindex="-1" role="dialog" aria-hidden="true">

		<div class="pswp__bg"></div>

		<div class="pswp__scroll-wrap">

			<div class="pswp__container">
				<div class="pswp__item"></div>
				<div class="pswp__item"></div>
				<div class="pswp__item"></div>
			</div>

			<div class="pswp__ui pswp__ui--hidden">

				<div class="pswp__top-bar">


					<div class="pswp__counter"></div>

					<button class="pswp__button pswp__button--close" title="<?php esc_attr_e( 'Close (Esc)', 'baroque' ) ?>"></button>

					<button class="pswp__button pswp__button--share" title="<?php esc_attr_e( 'Share', 'baroque' ) ?>"></button>

					<button class="pswp__button pswp__button--fs" title="<?php esc_attr_e( 'Toggle fullscreen', 'baroque' ) ?>"></button>

					<button class="pswp__button pswp__button--zoom" title="<?php esc_attr_e( 'Zoom in/out', 'baroque' ) ?>"></button>

					<div class="pswp__preloader">
						<div class="pswp__preloader__icn">
							<div class="pswp__preloader__cut">
								<div class="pswp__preloader__donut"></div>
							</div>
						</div>
					</div>
				</div>

				<div class="pswp__share-modal pswp__share-modal--hidden pswp__single-tap">
					<div class="pswp__share-tooltip"></div>
				</div>

				<button class="pswp__button pswp__button--arrow--left" title="<?php esc_attr_e( 'Previous (arrow left)', 'baroque' ) ?>">
				</button>

				<button class="pswp__button pswp__button--arrow--right" title="<?php esc_attr_e( 'Next (arrow right)', 'baroque' ) ?>">
				</button>

				<div class="pswp__caption">
					<div class="pswp__caption__center"></div>
				</div>

			</div>

		</div>

	</div>
	<?php
}

add_action( 'wp_footer', 'baroque_gallery_images_lightbox' );


/**
 * Adds preloader container at the bottom of the site
 */
function baroque_preloader() {
	if ( ! baroque_get_option( 'preloader' ) ) {
		return;
	}

	get_template_part( 'parts/preloader' );
}

add_action( 'baroque_after_footer', 'baroque_preloader' );