<?php
/**
 * Hooks for template header
 *
 * @package Baroque
 */

/**
 * Enqueue scripts and styles.
 *
 * @since 1.0
 */
function baroque_enqueue_scripts() {
	/**
	 * Register and enqueue styles
	 */

	if( baroque_get_option( 'font_families_typo' ) ) {
		wp_enqueue_style( 'baroque-fonts', baroque_fonts_url(), array(), '20161025' );
	}

	wp_register_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css', array(), '3.3.7' );
	wp_register_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css', array(), '4.6.3' );
	wp_register_style( 'eleganticons', get_template_directory_uri() . '/css/eleganticons.min.css', array(), '1.0.0' );
	wp_register_style( 'linearicons', get_template_directory_uri() . '/css/linearicons.min.css', array(), '1.0.0' );
	wp_register_style( 'ionicons', get_template_directory_uri() . '/css/ionicons.min.css', array(), '2.0.0' );
	wp_register_style( 'photoswipe', get_template_directory_uri() . '/css/photoswipe.css', array(), '4.1.1' );
	wp_register_style( 'fullpage', get_template_directory_uri() . '/css/jquery.fullPage.css', array(), '2.9.5' );
	wp_register_style( 'swiper', get_template_directory_uri() . '/css/swiper.min.css', array(), '3.4.2' );

	wp_enqueue_style(
		'baroque', get_template_directory_uri() . '/style.css', array(
		'bootstrap',
		'font-awesome',
		'eleganticons',
		'linearicons',
		'ionicons',
		'fullpage',
		'swiper',
	), '20161025'
	);

	wp_add_inline_style( 'baroque', baroque_customize_css() );

	/**
	 * Register and enqueue scripts
	 */
	$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	wp_enqueue_script( 'html5shiv', get_template_directory_uri() . '/js/plugins/html5shiv.min.js', array(), '3.7.2' );
	wp_script_add_data( 'html5shiv', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'respond', get_template_directory_uri() . '/js/plugins/respond.min.js', array(), '1.4.2' );
	wp_script_add_data( 'respond', 'conditional', 'lt IE 9' );

	wp_register_script( 'photoswipe', get_template_directory_uri() . '/js/plugins/photoswipe.min.js', array(), '4.1.1', true );
	wp_register_script( 'photoswipe-ui', get_template_directory_uri() . '/js/plugins/photoswipe-ui.min.js', array( 'photoswipe' ), '4.1.1', true );

	wp_register_script( 'sly', get_template_directory_uri() . '/js/plugins/sly.min.js', array(), '1.6.1' );
	wp_register_script( 'isotope', get_template_directory_uri() . '/js/plugins/isotope.pkgd.min.js', array( 'imagesloaded' ), '2.2.2', true );
	wp_register_script( 'flipclock', get_template_directory_uri() . '/js/plugins/flipclock.min.js', array(), '1.0', true );
	wp_register_script( 'counterup', get_template_directory_uri() . '/js/plugins/jquery.counterup.min.js', array(), '1.0', true );
	wp_register_script( 'easing', get_template_directory_uri() . '/js/plugins/jquery.easing.min.js', array(), '1.3', true );
	wp_register_script( 'fullpage', get_template_directory_uri() . '/js/plugins/jquery.fullPage.js', array(), '2.9.5', true );
	wp_register_script( 'parallax', get_template_directory_uri() . '/js/plugins/jquery.parallax.min.js', array(), '1.0', true );
	wp_register_script( 'tabs', get_template_directory_uri() . '/js/plugins/jquery.tabs.js', array(), '1.0', true );
	wp_register_script( 'swiper', get_template_directory_uri() . '/js/plugins/swiper.min.js', array(), '3.4.2', true );
	wp_register_script( 'slick', get_template_directory_uri() . '/js/plugins/slick.min.js', array(), '1.0', true );
	wp_register_script( 'pentip', get_template_directory_uri() . '/js/plugins/pentip.js', array(), '1.0', true );
	wp_register_script( 'waypoints', get_template_directory_uri() . '/js/plugins/waypoints.min.js', array( 'jquery' ), '2.0.2' );

	if ( is_singular() ) {

		wp_enqueue_style( 'photoswipe' );
		wp_enqueue_script( 'photoswipe-ui' );

		$photoswipe_skin = 'photoswipe-default-skin';
		if ( wp_style_is( $photoswipe_skin, 'registered' ) && ! wp_style_is( $photoswipe_skin, 'enqueued' ) ) {
			wp_enqueue_style( $photoswipe_skin );
		}
	}

	wp_enqueue_script(
		'baroque', get_template_directory_uri() . "/js/scripts$min.js", array(
		'jquery',
		'isotope',
		'imagesloaded',
		'waypoints',
		'sly',
		'flipclock',
		'counterup',
		'easing',
		'fullpage',
		'parallax',
		'tabs',
		'swiper',
		'slick',
		'pentip',
	), '20171013', true
	);

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}


	wp_localize_script(
		'baroque', 'baroqueData', array(
			'ajaxurl' => admin_url( 'admin-ajax.php' ),
			'isRTL'   => is_rtl(),
		)
	);
}

add_action( 'wp_enqueue_scripts', 'baroque_enqueue_scripts', 20 );

/**
 * Enqueues front-end CSS for theme customization
 */
function baroque_customize_css() {
	$css = '';

	// Logo
	$logo_size_width = intval( baroque_get_option( 'logo_width' ) );
	$logo_css        = $logo_size_width ? 'width:' . $logo_size_width . 'px; ' : '';

	$logo_size_height = intval( baroque_get_option( 'logo_height' ) );
	$logo_css .= $logo_size_height ? 'height:' . $logo_size_height . 'px; ' : '';

	$logo_margin = baroque_get_option( 'logo_position' );
	$logo_css .= $logo_margin['top'] ? 'margin-top:' . $logo_margin['top'] . '; ' : '';
	$logo_css .= $logo_margin['right'] ? 'margin-right:' . $logo_margin['right'] . '; ' : '';
	$logo_css .= $logo_margin['bottom'] ? 'margin-bottom:' . $logo_margin['bottom'] . '; ' : '';
	$logo_css .= $logo_margin['left'] ? 'margin-left:' . $logo_margin['left'] . '; ' : '';

	if ( ! empty( $logo_css ) ) {
		$css .= '.site-header .logo img ' . ' {' . $logo_css . '}';
	}

	/* 404 background */

	if ( is_page_template( 'template-coming-soon-page.php' ) ) {
		$banner   = baroque_get_option( 'coming_soon_background_image' );
		$bg_color = baroque_get_option( 'coming_soon_background_color' );

		if ( $banner ) {
			$css .= '.page-template-template-coming-soon-page { background-image: url( ' . esc_url( $banner ) . '); }';
		}

		if ( $bg_color ) {
			$css .= '.page-template-template-coming-soon-page:before { background-color: ' . $bg_color . '; }';
		}
	}

	/* Canvas Menu Bg*/
	$banner = baroque_get_option( 'canvas_menu_img' );

	if ( $banner ) {
		$css .= '.baroque-off-canvas-panel { background-image: url( ' . esc_url( $banner ) . '); }';
	}

	/* Color Scheme */
	$color_scheme_option = baroque_get_option( 'color_scheme' );

	if ( intval( baroque_get_option( 'custom_color_scheme' ) ) ) {
		$color_scheme_option = baroque_get_option( 'custom_color' );
	}

	// Don't do anything if the default color scheme is selected.
	if ( $color_scheme_option ) {
		$css .= baroque_get_color_scheme_css( $color_scheme_option );
	}

	$css .= baroque_typography_css();

	$css .= baroque_get_heading_typography_css();

	return $css;

}

/**
 * Display header
 */
function baroque_show_header() {
	if ( is_page_template( 'template-coming-soon-page.php' ) ) {
		get_template_part( 'parts/logo' );
	} else {
		get_template_part( 'parts/headers/header', baroque_get_option( 'header_layout' ) );
	}
}

add_action( 'baroque_header', 'baroque_show_header' );

/**
 * Display the header minimized
 *
 * @since 1.0.0
 */
function baroque_header_minimized() {

	if ( baroque_get_option( 'header_sticky' ) == false ) {
		return;
	}

	$css_class = 'mf-header-' . baroque_get_option( 'header_layout' );

	printf( '<div id="mf-header-minimized" class="mf-header-minimized %s"></div>', esc_attr( $css_class ) );

}

add_action( 'baroque_before_header', 'baroque_header_minimized', 15 );


/**
 * Display page header
 */
function baroque_page_header() {

	if ( baroque_is_homepage() ) {
		return;
	}

	if ( is_page_template( 'template-coming-soon-page.php' ) ) {
		return;
	}

	if ( baroque_is_blog() ) {
		get_template_part( 'parts/page-headers/blog' );
	} elseif ( baroque_is_portfolio() ) {
		get_template_part( 'parts/page-headers/portfolio' );
	} elseif ( baroque_is_catalog() ) {
		get_template_part( 'parts/page-headers/catalog' );
	} elseif ( function_exists( 'is_product' ) && is_product() ) {
		get_template_part( 'parts/page-headers/single-product' );
	} elseif ( is_page() ) {
		get_template_part( 'parts/page-headers/default' );
	} elseif ( is_search() ) {
		get_template_part( 'parts/page-headers/search' );
	}
}

add_action( 'baroque_after_header', 'baroque_page_header', 10 );

/**
 * Get breadcrumbs
 *
 * @since  1.0.0
 *
 * @return string
 */

if ( ! function_exists( 'baroque_get_breadcrumbs' ) ) :
	function baroque_get_breadcrumbs() {

		ob_start();
		?>
		<nav class="breadcrumbs">
			<?php
			baroque_breadcrumbs(
				array(
					'before'   => '',
					'taxonomy' => function_exists( 'is_woocommerce' ) && is_woocommerce() ? 'product_cat' : 'category',
				)
			);
			?>
		</nav>
		<?php
		echo ob_get_clean();
	}

endif;

/**
 * Filter to archive title and add page title for singular pages
 *
 * @param string $title
 *
 * @return string
 */
function baroque_the_archive_title( $title ) {
	if ( is_search() ) {
		$title = esc_html__( 'Search Results', 'baroque' );

	} elseif ( is_404() ) {
		$title = esc_html__( 'Page Not Found', 'baroque' );

	} elseif ( is_page() ) {
		$title = get_post_meta( get_the_ID(), 'custom_title', true );
		$title = wp_kses( $title, wp_kses_allowed_html( 'post' ) );
		if ( ! $title ) {
			$title = get_the_title();
		}

	} elseif ( is_home() && is_front_page() ) {
		$title = esc_html__( 'The Latest Posts', 'baroque' );

	} elseif ( is_home() && ! is_front_page() ) {
		$title = wp_kses( baroque_get_option( 'blog_page_header_title' ), wp_kses_allowed_html( 'post' ) );

		if ( ! $title ) {
			$title = get_the_title( get_option( 'page_for_posts' ) );
		}

	} elseif ( function_exists( 'is_shop' ) && is_shop() ) {
		$title = wp_kses( baroque_get_option( 'catalog_page_title' ), wp_kses_allowed_html( 'post' ) );
		if ( ! $title ) {
			$title = get_the_title( get_option( 'woocommerce_shop_page_id' ) );
		}

	} elseif ( function_exists( 'is_product' ) && is_product() ) {
		$cats = get_the_terms( get_the_ID(), 'product_cat' );
		if ( ! is_wp_error( $cats ) && $cats ) {
			$title = $cats[0]->name;
		} else {
			$title = get_the_title( get_option( 'woocommerce_shop_page_id' ) );
		}

	} elseif ( baroque_is_portfolio() ) {
		$title = wp_kses( baroque_get_option( 'portfolio_page_header_title' ), wp_kses_allowed_html( 'post' ) );
		if ( ! $title ) {
			if ( get_option( 'baroque_portfolio_page_id' ) ) {
				$title = get_the_title( get_option( 'baroque_portfolio_page_id' ) );
			} else {
				$title = esc_html__( 'Portfolio', 'baroque' );
			}
		}

	} elseif ( baroque_is_service() ) {
		if ( get_option( 'baroque_service_page_id' ) ) {
			$title = get_the_title( get_option( 'baroque_service_page_id' ) );
		} else {
			$title = esc_html__( 'Services', 'baroque' );
		}

	} elseif ( is_singular( 'portfolio' ) ) {
		$cats = get_the_terms( get_the_ID(), 'portfolio_category' );
		if ( $cats ) {
			$title = $cats[0]->name;
		} elseif ( get_option( 'baroque_portfolio_page_id' ) ) {
			$title = get_the_title( get_option( 'baroque_portfolio_page_id' ) );
		} else {
			$title = esc_html__( 'Portfolio', 'baroque' );
		}

	} elseif ( is_singular( 'service' ) ) {
		$cats = get_the_terms( get_the_ID(), 'service_category' );
		if ( $cats ) {
			$title = $cats[0]->name;
		} elseif ( get_option( 'baroque_service_page_id' ) ) {
			$title = get_the_title( get_option( 'baroque_service_page_id' ) );
		} else {
			$title = esc_html__( 'Service', 'baroque' );
		}

	} elseif ( is_tax() || is_category() ) {
		$title = single_term_title( '', false );

	} elseif ( is_singular( 'post' ) ) {
		$terms = get_the_category();
		if ( $terms && ! is_wp_error( $terms ) ) {
			$title = $terms[0]->name;
		} else {
			$title = get_the_title( get_option( 'page_for_posts' ) );
		}
	}

	return $title;
}

add_filter( 'get_the_archive_title', 'baroque_the_archive_title' );

/**
 * Header Video
 */
function baroque_header_video() {
	$header_banner = get_post_meta( get_the_ID(), 'header_banner', true );
	$type          = get_post_meta( get_the_ID(), 'background_type', true );
	$image         = get_post_meta( get_the_ID(), 'background_image', true );
	$video         = get_post_meta( get_the_ID(), 'video_url', true );
	$shortcode     = get_post_meta( get_the_ID(), 'shortcode', true );
	$height        = get_post_meta( get_the_ID(), 'height', true );
	$text_color    = get_post_meta( get_the_ID(), 'text_color', true );
	$title         = get_post_meta( get_the_ID(), 'title', true );
	$subtitle      = get_post_meta( get_the_ID(), 'subtitle', true );

	if ( ! $header_banner ) {
		return;
	}

	if ( ! baroque_is_homepage() ) {
		return;
	}

	// Handle Height
	if ( ! empty( $height ) ) {
		$height = preg_replace( '/\s+/', '', $height );

		$pattern = '/^(\d*(?:\.\d+)?)\s*(px|\%|in|cm|mm|em|rem|ex|pt|pc|vw|vh|vmin|vmax)?$/';
		// allowed metrics: http://www.w3schools.com/cssref/css_units.asp
		$regexr = preg_match( $pattern, $height, $matches );
		$value  = isset( $matches[1] ) ? (float) $matches[1] : (float) $height;
		$unit   = isset( $matches[2] ) ? $matches[2] : 'px';
		$height = $value . $unit;
	}

	$output  = '';
	$html    = array();
	$classes = array(
		'header-video',
		'text-' . $text_color
	);

	if ( $title ) {
		$html[] = sprintf( '<h2 class="banner-title">%s</h2>', $title );
	}

	if ( $subtitle ) {
		$html[] = sprintf( '<div class="subtitle">%s</div>', $subtitle );
	}

	if ( $type == 'image' ) {

		if ( $image ) {
			$output = sprintf(
				'<div class="featured-image" style="background-image:url(%s)"></div>',
				esc_url( wp_get_attachment_image_url( $image, 'full' ) )
			);
		}

	} elseif ( $type == 'video' ) {
		$embed_wp = new WP_Embed();

		$embed = '';
		if ( is_object( $embed_wp ) ) {
			$embed = $embed_wp->run_shortcode( '[embed]' . $video . '[/embed]' );
		}

		$output = sprintf( '<div class="video-wrapper">%s</div>', $embed );

	} elseif ( $type == 'revslider' ) {
		$output = sprintf( '<div class="video-wrapper rev-banner">%s</div>', do_shortcode( $shortcode ) );
	}

	$style_css = '';
	if ( $height ) {
		$style_css = sprintf( 'style="height:%s"', $height );
	}

	printf(
		'<div class="%s" %s>
			%s
			<div class="banner-content">%s</div>
		</div>',
		esc_attr( implode( ' ', $classes ) ),
		$style_css,
		$output,
		implode( '', $html )
	);
}

add_action( 'baroque_before_header', 'baroque_header_video', 10 );

/**
 * Returns CSS for the color schemes.
 *
 *
 * @param array $colors Color scheme colors.
 *
 * @return string Color scheme CSS.
 */
function baroque_get_color_scheme_css( $colors ) {
	return <<<CSS

	/* Background Color */

	.primary-background-color,
	ul.nav-filter li a.active,ul.nav-filter li a:hover,
	.site-menu ul .extra-cart-item .cart-contents .mini-cart-counter,
	.woocommerce .widget_shopping_cart_content .buttons a,.widget_shopping_cart_content .buttons a,
	.woocommerce .widget_shopping_cart_content .buttons a:hover,.widget_shopping_cart_content .buttons a:hover,.woocommerce .widget_shopping_cart_content .buttons a:focus,.widget_shopping_cart_content .buttons a:focus,.woocommerce .widget_shopping_cart_content .buttons a:active,.widget_shopping_cart_content .buttons a:active,.woocommerce .widget_shopping_cart_content .buttons a:active:hover,.widget_shopping_cart_content .buttons a:active:hover,.woocommerce .widget_shopping_cart_content .buttons a:active:focus,.widget_shopping_cart_content .buttons a:active:focus,
	.woocommerce .widget_shopping_cart_content .buttons a:hover,.widget_shopping_cart_content .buttons a:hover,.woocommerce .widget_shopping_cart_content .buttons a:focus,.widget_shopping_cart_content .buttons a:focus,.woocommerce .widget_shopping_cart_content .buttons a:active,.widget_shopping_cart_content .buttons a:active,.woocommerce .widget_shopping_cart_content .buttons a:active:hover,.widget_shopping_cart_content .buttons a:active:hover,.woocommerce .widget_shopping_cart_content .buttons a:active:focus,.widget_shopping_cart_content .buttons a:active:focus,
	.numeric-navigation .page-numbers:hover,.numeric-navigation .page-numbers.current,
	.btn-primary,
	.btn-primary:hover,.btn-primary:focus,.btn-primary:active,.btn-primary:active:hover,.btn-primary:active:focus,
	.owl-nav div:hover,
	.owl-dots .owl-dot.active span,.owl-dots .owl-dot:hover span,
	.slick-dots li:hover,.slick-dots li.slick-active,
	.page-template-template-home-boxed,
	.blog-masonry .blog-wrapper:hover .entry-summary,
	.blog-list .blog-wrapper:hover .entry-summary,
	.backtotop.style-2,
	.portfolio-grid-wide .hover-border:before,.portfolio-metro .hover-border:before,.portfolio-masonry .hover-border:before,.portfolio-grid-wide .hover-border:after,.portfolio-metro .hover-border:after,.portfolio-masonry .hover-border:after,
	.portfolio-grid-wide .hover-border div:before,.portfolio-metro .hover-border div:before,.portfolio-masonry .hover-border div:before,.portfolio-grid-wide .hover-border div:after,.portfolio-metro .hover-border div:after,.portfolio-masonry .hover-border div:after,
	.portfolio-carousel .portfolio-carousel-wrapper .pages li.active:before,
	.comment-respond .form-submit .submit,
	.comment-respond .form-submit .submit:hover,.comment-respond .form-submit .submit:focus,.comment-respond .form-submit .submit:active,.comment-respond .form-submit .submit:active:hover,.comment-respond .form-submit .submit:active:focus,
	.comment-respond .form-submit .submit:hover,.comment-respond .form-submit .submit:focus,.comment-respond .form-submit .submit:active,.comment-respond .form-submit .submit:active:hover,.comment-respond .form-submit .submit:active:focus,
	.woocommerce a.button,.woocommerce button.button,.woocommerce input.button,.woocommerce #respond input#submit,
	.woocommerce a.button:hover,.woocommerce button.button:hover,.woocommerce input.button:hover,.woocommerce #respond input#submit:hover,.woocommerce a.button:focus,.woocommerce button.button:focus,.woocommerce input.button:focus,.woocommerce #respond input#submit:focus,.woocommerce a.button:active,.woocommerce button.button:active,.woocommerce input.button:active,.woocommerce #respond input#submit:active,.woocommerce a.button:active:hover,.woocommerce button.button:active:hover,.woocommerce input.button:active:hover,.woocommerce #respond input#submit:active:hover,.woocommerce a.button:active:focus,.woocommerce button.button:active:focus,.woocommerce input.button:active:focus,.woocommerce #respond input#submit:active:focus,
	.woocommerce a.button:hover,.woocommerce button.button:hover,.woocommerce input.button:hover,.woocommerce #respond input#submit:hover,.woocommerce a.button:focus,.woocommerce button.button:focus,.woocommerce input.button:focus,.woocommerce #respond input#submit:focus,.woocommerce a.button:active,.woocommerce button.button:active,.woocommerce input.button:active,.woocommerce #respond input#submit:active,.woocommerce a.button:active:hover,.woocommerce button.button:active:hover,.woocommerce input.button:active:hover,.woocommerce #respond input#submit:active:hover,.woocommerce a.button:active:focus,.woocommerce button.button:active:focus,.woocommerce input.button:active:focus,.woocommerce #respond input#submit:active:focus,
	.woocommerce a.button.alt,.woocommerce button.button.alt,.woocommerce input.button.alt,.woocommerce #respond input#submit.alt,
	.woocommerce a.button.alt:hover,.woocommerce button.button.alt:hover,.woocommerce input.button.alt:hover,.woocommerce #respond input#submit.alt:hover,.woocommerce a.button.alt:focus,.woocommerce button.button.alt:focus,.woocommerce input.button.alt:focus,.woocommerce #respond input#submit.alt:focus,.woocommerce a.button.alt:active,.woocommerce button.button.alt:active,.woocommerce input.button.alt:active,.woocommerce #respond input#submit.alt:active,.woocommerce a.button.alt:active:hover,.woocommerce button.button.alt:active:hover,.woocommerce input.button.alt:active:hover,.woocommerce #respond input#submit.alt:active:hover,.woocommerce a.button.alt:active:focus,.woocommerce button.button.alt:active:focus,.woocommerce input.button.alt:active:focus,.woocommerce #respond input#submit.alt:active:focus,
	.woocommerce a.button.alt:hover,.woocommerce button.button.alt:hover,.woocommerce input.button.alt:hover,.woocommerce #respond input#submit.alt:hover,.woocommerce a.button.alt:focus,.woocommerce button.button.alt:focus,.woocommerce input.button.alt:focus,.woocommerce #respond input#submit.alt:focus,.woocommerce a.button.alt:active,.woocommerce button.button.alt:active,.woocommerce input.button.alt:active,.woocommerce #respond input#submit.alt:active,.woocommerce a.button.alt:active:hover,.woocommerce button.button.alt:active:hover,.woocommerce input.button.alt:active:hover,.woocommerce #respond input#submit.alt:active:hover,.woocommerce a.button.alt:active:focus,.woocommerce button.button.alt:active:focus,.woocommerce input.button.alt:active:focus,.woocommerce #respond input#submit.alt:active:focus,
	.woocommerce div.product div.summary .single_add_to_cart_button,
	.woocommerce-cart .woocommerce table.cart .btn-shop,.woocommerce-cart .woocommerce table.checkout .btn-shop,
	.woocommerce-cart .woocommerce table.cart .btn-shop:hover,.woocommerce-cart .woocommerce table.checkout .btn-shop:hover,.woocommerce-cart .woocommerce table.cart .btn-shop:focus,.woocommerce-cart .woocommerce table.checkout .btn-shop:focus,.woocommerce-cart .woocommerce table.cart .btn-shop:active,.woocommerce-cart .woocommerce table.checkout .btn-shop:active,.woocommerce-cart .woocommerce table.cart .btn-shop:active:hover,.woocommerce-cart .woocommerce table.checkout .btn-shop:active:hover,.woocommerce-cart .woocommerce table.cart .btn-shop:active:focus,.woocommerce-cart .woocommerce table.checkout .btn-shop:active:focus,
	.woocommerce-cart .woocommerce table.cart .btn-shop:hover,.woocommerce-cart .woocommerce table.checkout .btn-shop:hover,.woocommerce-cart .woocommerce table.cart .btn-shop:focus,.woocommerce-cart .woocommerce table.checkout .btn-shop:focus,.woocommerce-cart .woocommerce table.cart .btn-shop:active,.woocommerce-cart .woocommerce table.checkout .btn-shop:active,.woocommerce-cart .woocommerce table.cart .btn-shop:active:hover,.woocommerce-cart .woocommerce table.checkout .btn-shop:active:hover,.woocommerce-cart .woocommerce table.cart .btn-shop:active:focus,.woocommerce-cart .woocommerce table.checkout .btn-shop:active:focus,
	.ba-member .hover-border:before,.ba-member .hover-border:after,
	.ba-member .hover-border div:before,.ba-member .hover-border div:after,
	.ba-member .member-content .name:after,
	.ba-hero-slider .slider-grid-content .item-content.active .item-inner,
	.ba-hero-slider .slider-grid-content .item-inner:hover,
	.ba-vs-slider3 .slider-content .link:after,
	.vc_progress_bar.vc_progress-bar-color-custom .vc_single_bar .vc_bar,
	.wpcf7-form .wpcf7-submit,
	.wpcf7-form .wpcf7-submit:hover,.wpcf7-form .wpcf7-submit:focus,.wpcf7-form .wpcf7-submit:active,.wpcf7-form .wpcf7-submit:active:hover,.wpcf7-form .wpcf7-submit:active:focus,
	.wpcf7-form .wpcf7-submit:hover,.wpcf7-form .wpcf7-submit:focus,.wpcf7-form .wpcf7-submit:active,.wpcf7-form .wpcf7-submit:active:hover,.wpcf7-form .wpcf7-submit:active:focus,
	.mc4wp-form input[type="submit"],
	.baroque-dark.page-template-template-home-boxed,
	.baroque-dark.blog-list .blog-wrapper:hover .entry-summary,.baroque-dark.blog-masonry .blog-wrapper:hover .entry-summary
	{background-color: $colors}

	/* Border Color */

	ul.nav-filter li a.active,ul.nav-filter li a:hover,
	.owl-nav div:hover,
	.ba-portfolios-grid-gap .ports-footer .text:hover,
	.ba-hero-slider .slider-grid-content .item-content.active .item-inner,
	.ba-hero-slider .slider-grid-content .item-inner:hover,
	.ba-portfolio-quote,
	.post-author .post-author-box
	{border-color: $colors}

	/* Color */
	.primary-color,
	.baroque-off-canvas-panel.menu-sidebar .sidebar-language li.actived a,
	.baroque-off-canvas-panel.menu-sidebar .baroque-social-links-widget a:hover,
	.site-menu .extra-language-item li:hover a,
	.woocommerce .widget_shopping_cart_content ul.cart_list .mini_cart_item a:hover,.widget_shopping_cart_content ul.cart_list .mini_cart_item a:hover,
	.page-template-template-homepage.header-light .site-menu .extra-language-item a:hover,.page-template-template-home-boxed.header-light .site-menu .extra-language-item a:hover,
	.menu-area ul.menu > li:hover > a,
	.menu-area .menu .is-mega-menu .dropdown-submenu .menu-item-mega > a:hover,
	.paging-navigation .nav-links a:hover,
	.paging-navigation.style-2 .nav-previous-ajax a,
	.page-template-template-coming-soon-page .coming-soon-socials a:hover,
	.entry-meta a,
	.entry-footer .tag-list a:hover,
	.sticky .blog-wrapper .entry-title:before,
	.blog-wrapper:hover .read-more,
	.baroque-taxs-list li a:hover,.baroque-taxs-list li a.selected,
	.blog-text .baroque-taxs-list li a:hover,.blog-text .baroque-taxs-list li a.selected,
	.blog-text .entry-title a:hover,
	.error404 .error-404 .page-content a,
	.portfolio-grid .portfolio-inner:hover .read-more,
	.widget_categories li a:hover,.widget_recent_comments li a:hover,.widget_rss li a:hover,.widget_pages li a:hover,.widget_archive li a:hover,.widget_nav_menu li a:hover,.widget_recent_entries li a:hover,.widget_meta li a:hover,.widget-recent-comments li a:hover,
	.widget_tag_cloud a:hover,
	.popular-posts-widget .mini-widget-title h4:hover a,
	.widget-about a:hover,
	.baroque-social-links-widget a:hover,
	.woocommerce ul.products li.product.product-category:hover .woocommerce-loop-category__title,.woocommerce ul.products li.product.product-category:hover .count,
	.woocommerce ul.products li.product .un-product-thumbnail .footer-button > a:hover,
	.woocommerce div.product span.price,.woocommerce div.product p.price,
	.woocommerce div.product .woocommerce-tabs ul.tabs li.active a,
	.woocommerce .shop-toolbar .product-found span,
	.woocommerce .un-categories-filter ul li a:hover,.woocommerce .un-categories-filter ul li a.selected,
	.woocommerce-account .woocommerce .woocommerce-Addresses .woocommerce-Address .woocommerce-Address-edit .edit:hover,
	.shop-sidebar .widget_product_categories ul li.current-cat a,.shop-sidebar .widget_product_categories ul li.chosen a,.shop-sidebar .widget_product_categories ul li.current-cat .count,.shop-sidebar .widget_product_categories ul li.chosen .count,
	.ba-service:hover .read-more,
	.ba-image-box .service-summary .subtitle,
	.ba-member .member-content .socials a:hover,
	.ba-newletter .mc4wp-form:after,
	.ba-portfolios-grid-gap .ports-footer .text:hover,
	.ba-vs-slider3 .button-link:hover,
	.ba-vs-slider3 .ba-button-white:hover,
	.ba-hs-slider .slider-content .link:hover,
	.wpb-js-composer div .vc_tta.vc_tta-accordion .vc_tta-panel.vc_active .vc_tta-panel-title > a,.wpb-js-composer div .vc_tta.vc_tta-accordion .vc_tta-panel:hover .vc_tta-panel-title > a,
	.wpb-js-composer div .vc_tta.vc_tta-accordion .vc_tta-panel.vc_active .vc_tta-controls-icon.vc_tta-controls-icon-chevron:after,.wpb-js-composer div .vc_tta.vc_tta-accordion .vc_tta-panel:hover .vc_tta-controls-icon.vc_tta-controls-icon-chevron:after,
	.wpb-js-composer div .vc_tta-tabs-position-top.vc_tta-color-white.vc_tta-style-classic .vc_tta-tab.vc_active > a,.wpb-js-composer div .vc_tta-tabs-position-top.vc_tta-color-white.vc_tta-style-classic .vc_tta-tab:hover > a,
	.baroque-dark .baroque-off-canvas-panel.menu-sidebar .sidebar-language li.actived a,
	.baroque-dark .baroque-off-canvas-panel.menu-sidebar .baroque-social-links-widget a:hover,
	.baroque-dark .menu-area .menu .is-mega-menu .dropdown-submenu .menu-item-mega > a:hover,
	.baroque-dark.blog-text .baroque-taxs-list li a:hover,.baroque-dark.blog-text .baroque-taxs-list li a.selected,.baroque-dark .portfolio-navigation a:hover,.baroque-dark .blog-wrapper:hover .read-more,
	.baroque-dark .widget_categories li a:hover,.baroque-dark .widget_recent_comments li a:hover,.baroque-dark .widget_rss li a:hover,.baroque-dark .widget_pages li a:hover,.baroque-dark .widget_archive li a:hover,.baroque-dark .widget_nav_menu li a:hover,.baroque-dark .widget_recent_entries li a:hover,.baroque-dark .widget_meta li a:hover,.baroque-dark .widget-recent-commentsli a:hover,.baroque-dark .widget_tag_cloud a:hover,.baroque-dark .baroque-social-links-widget a:hover,
	.baroque-dark .popular-posts-widget .mini-widget-title h4:hover a,
	.baroque-dark .paging-navigation .nav-links a:hover,
	.baroque-dark .ba-service:hover .read-more,.baroque-dark .ba-vs-slider3 .button-link:hover,.baroque-dark .ba-member .member-content .socials a:hover,.baroque-dark .ba-hs-slider .swiper-button-white:hover,.baroque-dark .ba-hs-slider .slider-content .link:hover,
	.baroque-dark.woocommerce .shop-toolbar .woocommerce-ordering li > ul li a.active,.baroque-dark .woocommerce .shop-toolbar .woocommerce-ordering li > ul li a.active,.baroque-dark.woocommerce .shop-toolbar .woocommerce-ordering li > ul li a:hover,.baroque-dark .woocommerce .shop-toolbar .woocommerce-ordering li > ul li a:hover,.baroque-dark.woocommerce div.product .product_meta > span a:hover,.baroque-dark .woocommerce div.product .product_meta > span a:hover,
	.baroque-dark .shop-sidebar .widget ul li:hover > a,.baroque-dark .shop-sidebar .widget ul li:hover .count,
	.baroque-dark .primary-color,
	ul.wp-block-categories li a:hover
	{color: $colors}

	/* Other */
	.portfolio-carousel .portfolio-carousel-wrapper .scrollbar .handle
	{background: $colors}

CSS;
}

if ( ! function_exists( 'baroque_typography_css' ) ) :
	/**
	 * Get typography CSS base on settings
	 *
	 * @since 1.1.6
	 */
	function baroque_typography_css() {
		$css        = '';

		if ( ! class_exists( 'Kirki' ) ) {
			return $css;
		}

		$properties = array(
			'font-family'    => 'font-family',
			'font-size'      => 'font-size',
			'variant'        => 'font-weight',
			'line-height'    => 'line-height',
			'letter-spacing' => 'letter-spacing',
			'color'          => 'color',
			'text-transform' => 'text-transform',
			'text-align'     => 'text-align',
		);

		$settings = array(
			'body_typo'        => 'body',
			'heading1_typo'    => 'h1',
			'heading2_typo'    => 'h2',
			'heading3_typo'    => 'h3',
			'heading4_typo'    => 'h4',
			'heading5_typo'    => 'h5',
			'heading6_typo'    => 'h6',
			'menu_typo'        => '.main-nav a, .mf-header-item-button a, .primary-mobile-nav ul.menu > li > a',
			'sub_menu_typo'    => '.main-nav li li a, .primary-mobile-nav ul.menu ul li a',
			'menu_sidebar_typo'        => '.baroque-off-canvas-panel.menu-sidebar .menu > li > a',
			'sub_menu_sidebar_typo'    => '.baroque-off-canvas-panel.menu-sidebar .menu .sub-menu li a',
			'footer_text_typo' => '.site-footer',
		);

		foreach ( $settings as $setting => $selector ) {
			$typography = baroque_get_option( $setting );
			$default    = (array) baroque_get_option_default( $setting );
			$style      = '';

			foreach ( $properties as $key => $property ) {
				if ( isset( $typography[$key] ) && ! empty( $typography[$key] ) ) {
					if ( isset( $default[$key] ) && strtoupper( $default[$key] ) == strtoupper( $typography[$key] ) ) {
						continue;
					}

					$value = $typography[$key];

					if ( 'font-family' == $key ) {
						if (
							trim( $typography[$key] ) != '' &
							trim( $typography[$key] ) != ','
						) {
							$value = '"' . rtrim( trim( $typography[$key] ), ',' ) . '"';

							$style .= 'font-family:' . $value . ', Arial, sans-serif;';
						}
					} else {
						$value = 'variant' == $key ? str_replace( 'regular', '400', $value ) : $value;

						if ( $value ) {
							$style .= $property . ': ' . $value . ';';
						}
					}
				}
			}

			if ( ! empty( $style ) ) {
				$css .= $selector . '{' . $style . '}';
			}
		}

		return $css;
	}
endif;

/**
 * Returns CSS for the typography.
 *
 * @return string typography CSS.
 */
function baroque_get_heading_typography_css() {

	$headings   = array(
		'h1' => 'heading1_typo',
		'h2' => 'heading2_typo',
		'h3' => 'heading3_typo',
		'h4' => 'heading4_typo',
		'h5' => 'heading5_typo',
		'h6' => 'heading6_typo',
	);
	$inline_css = '';
	foreach ( $headings as $heading ) {
		$keys = array_keys( $headings, $heading );
		if ( $keys ) {
			$inline_css .= baroque_get_heading_font( $keys[0], $heading );
		}
	}


	return $inline_css;

}

/**
 * Returns CSS for the typography.
 *
 *
 * @param array $body_typo Color scheme body typography.
 *
 * @return string typography CSS.
 */
function baroque_get_heading_font( $key, $heading ) {

	$inline_css   = '';
	$heading_typo = baroque_get_option( $heading );

	if ( $heading_typo ) {
		if ( isset( $heading_typo['font-family'] ) && strtolower( $heading_typo['font-family'] ) !== 'hind' ) {
			$inline_css .= $key . '{font-family:' . rtrim( trim( $heading_typo['font-family'] ), ',' ) . ', Arial, sans-serif}';
		}
	}

	if ( empty( $inline_css ) ) {
		return;
	}

	return <<<CSS
	{$inline_css}
CSS;
}