<?php
/**
 * Custom functions for header.
 *
 * @package Baroque
 */

/**
 * Get Menu extra menu toggle
 *
 * @since  1.0.0
 *
 *
 * @return string
 */
function baroque_menu_icon() {
	$extras = baroque_get_option( 'menu_extras' );

	if ( empty( $extras ) || ! in_array( 'menu', $extras ) ) {
		return '';
	}

	$label = baroque_get_option( 'menu_label' );
	?>
	<li class="extra-menu-item extra-item">
		<a href="#" class="menu-toggle" id="icon-menu-sidebar">
			<?php
			if ( $label ) {
				echo '<span>' . wp_kses( $label, wp_kses_allowed_html( 'post' ) ) . '</span>';
			}
			?>
			<i class="icon-menu"></i>
		</a>
	</li>
	<?php
}

/**
 * Get Menu extra cart
 *
 * @since  1.0.0
 *
 *
 * @return string
 */
if ( ! function_exists( 'baroque_extra_cart' ) ) :
	function baroque_extra_cart() {
		$extras = baroque_get_option( 'menu_extras' );

		if ( empty( $extras ) || ! in_array( 'cart', $extras ) ) {
			return '';
		}

		if ( ! function_exists( 'woocommerce_mini_cart' ) ) {
			return '';
		}
		global $woocommerce;

		$mini_content = '';

		ob_start();
		woocommerce_mini_cart();
		$mini_cart = ob_get_clean();

		$mini_content = sprintf( '	<div class="widget_shopping_cart_content">%s</div>', $mini_cart );

		$icon_cart = '<i class="t-icon icon-bag2"></i>';
		$icon_cart = apply_filters( 'baroque_icon_cart', $icon_cart );

		printf(
			'<li class="extra-cart-item extra-item">
				<a class="cart-contents" id="icon-cart-contents" href="%s">
				%s
				<span class="mini-cart-counter">
					%s
				</span>
			</a>
			<div class="nx-mini-cart-content">
			%s
			</div>
			</li>',
			esc_url( wc_get_cart_url() ),
			$icon_cart,
			intval( $woocommerce->cart->cart_contents_count ),
			$mini_content
		);

	}
endif;

/**
 * Get Menu extra cart
 *
 * @since  1.0.0
 *
 *
 * @return string
 */
if ( ! function_exists( 'baroque_extra_language' ) ) :
	function baroque_extra_language() {
		$extras = baroque_get_option( 'menu_extras' );

		if ( empty( $extras ) || ! in_array( 'language', $extras ) ) {
			return '';
		}

		$language_html = baroque_language_switcher();

		if ( ! empty( $language_html ) ) {
			?>
			<li class="extra-language-item extra-item">
				<?php
				echo apply_filters( 'baroque_language_switcher_menu', $language_html );
				?>
			</li>
			<?php
		}

	}
endif;

/**
 * Display socials in footer
 *
 * @since 1.0.0
 */

if ( ! function_exists( 'baroque_get_socials_html' ) ) :
	function baroque_get_socials_html( $socials_options ) {

		if ( ! $socials_options ) {
			return;
		}

		$socials = baroque_get_socials();

		if ( $socials_options ) {

			printf( '<div class="socials">' );
			foreach ( $socials_options as $social ) {
				foreach ( $socials as $name => $label ) {
					if ( isset( $social['link_url'] ) ) {
						$link_url = $social['link_url'];
					} else {
						$link_url = $social;
					}

					if ( preg_match( '/' . $name . '/', $link_url ) ) {

						if ( $name == 'google' ) {
							$name = 'googleplus';
						}

						if ( $name == 'vk' ) {
							printf( '<a href="%s" target="_blank" class="font-fa share-social share-%s"><i class="social fa fa-%s"></i></a>', esc_url( $link_url ), esc_attr( $name ), esc_attr( $name ) );
						} else {
							printf( '<a class="share-social share-%s" href="%s" target="_blank"><i class="social social_%s"></i></a>', esc_attr( $name ), esc_url( $link_url ), esc_attr( $name ) );
						}

						break;

					}

				}
			}
		}
		printf( '</div>' );
	}

endif;


/**
 * Wrapper function to deal with backwards compatibility.
 */
if ( ! function_exists( 'baroque_body_open' ) ) {
	function baroque_body_open() {
		if ( function_exists( 'wp_body_open' ) ) {
			wp_body_open();
		} else {
			do_action( 'wp_body_open' );
		}
	}
}