<?php
/**
 * @package Baroque
 */

global $wp_query, $ba_portfolio_attr;

$current = $wp_query->current_post + 1;

$p_style   = baroque_get_option( 'portfolio_style' );
$size      = 'baroque-blog-grid';
$css       = 'portfolio-wrapper';
$css_inner = '';
$style     = '';

$thumbnail_url = get_the_post_thumbnail_url( get_the_ID(), 'full' );

$gallery = get_post_meta( get_the_ID(), 'images', false );

if ( isset( $ba_portfolio_attr['style'] ) ) {
	$p_style = $ba_portfolio_attr['style'];

	if ( isset( $ba_portfolio_attr['index'] ) ) {
		$current = $ba_portfolio_attr['index'];
	}
}

if ( $p_style == 'grid' ) {
	$css .= ' col-md-4 col-sm-6 col-xs-12';
	if ( $gallery ) {
		$css .= ' has-gallery';
	}

} elseif ( $p_style == 'grid-wide' ) {
	$size = 'baroque-portfolio-grid-wide';
	$css .= ' col-md-3 col-sm-6 col-xs-12';

} elseif ( $p_style == 'list' ) {
	$size = 'baroque-blog-classic';

} elseif ( $p_style == 'masonry' ) {
	$css .= ' col-md-3 col-sm-6 col-xs-12';

	if ( $current % 9 == 0 ) {
		$size = 'baroque-portfolio-masonry-3';
	} elseif ( $current % 9 == 2 || $current % 9 == 5 || $current % 9 == 7 ) {
		$size = 'baroque-portfolio-masonry-2';
	} else {
		$size = 'baroque-portfolio-carousel';
	}

} elseif ( $p_style == 'carousel' ) {
	$size = 'baroque-portfolio-carousel';
	$css .= ' swiper-slide';

} elseif ( $p_style == 'metro' ) {
	$css .= ' col-md-6 col-sm-6 col-xs-12';

	if ( $current % 2 == 1 ) {
		$size = 'baroque-portfolio-carousel';
	} else {
		$size = 'baroque-portfolio-metro-2';
	}

} elseif ( $p_style == 'parallax' ) {
	$size = apply_filters( 'baroque_portfolio_single_image_size', 'baroque-portfolio-single' );
	$css .= ' section';
	$css_inner = 'container';
	$style     = 'background-image:url( ' . esc_url( $thumbnail_url ) . ' )';
}

$btn = baroque_get_option( 'portfolio_content_button' );

$readmore_html = sprintf(
	'<a href="%s" class="read-more">
		%s<i class="icon-plus"></i>
	</a>',
	get_the_permalink(),
	esc_html( $btn )
);

?>
<div id="post-<?php the_ID(); ?>" <?php post_class( $css ); ?> style="<?php echo esc_attr( $style ) ?>">
	<?php if ( $p_style == 'parallax' ) : ?>
		<a href="<?php the_permalink() ?>" class="port-link"></a>
	<?php endif ?>

	<div class="portfolio-inner <?php echo esc_attr( $css_inner ) ?>">

		<?php if ( $p_style != 'parallax' ) : ?>

			<div class="hover-border">
				<div></div>
			</div>
			<a href="<?php the_permalink() ?>" class="port-link"></a>

			<div class="entry-thumbnail">
				<a href="<?php the_permalink() ?>">
					<?php the_post_thumbnail( $size ); ?>
					<?php
					if ( ( $p_style == 'grid' ) && $gallery ) {
						the_post_thumbnail( $size, array( 'class' => 'image-hover' ) );
						echo wp_get_attachment_image( $gallery[0], $size, '', array( 'class' => 'image-hover' ) );
					}
					?>
				</a>

				<?php if ( ( $p_style == 'grid' ) && ! empty( $btn ) ) : ?>
					<?php echo wp_kses_post( $readmore_html ); ?>
				<?php endif ?>
			</div>

		<?php endif ?>

		<div class="entry-summary">
			<div class="summary-header">
				<?php
				$category = get_the_terms( get_the_ID(), 'portfolio_category' );

				if ( ! is_wp_error( $category ) && $category ) {
					echo sprintf(
						'<a href="%s" class="portfolio-cat">%s</a>',
						esc_url( get_term_link( $category[0], 'category' ) ),
						esc_html( $category[0]->name )
					);
				}
				?>

				<h2 class="entry-title"><a href="<?php the_permalink() ?>"><?php the_title() ?></a></h2>

				<?php if ( $p_style == 'list' ) : ?>
					<div class="excerpt"><?php the_excerpt(); ?></div>
				<?php endif ?>

			</div>

			<?php if ( ( $p_style == 'list' || $p_style == 'parallax' ) && ! empty( $btn ) ) : ?>
				<?php echo wp_kses_post( $readmore_html ); ?>
			<?php endif ?>

		</div>

	</div>
</div><!-- #project-## -->
