<?php
/**
 * The template part for displaying related posts
 *
 * @package Sober
 */

// Only support posts
if ( 'post' != get_post_type() ) {
	return;
}

if ( ! intval( baroque_get_option( 'related_posts' ) ) ) {
	return;
}

if ( get_post_meta( get_the_ID(), 'custom_page_layout', true ) ) {
	$layout = get_post_meta( get_the_ID(), 'layout', true );
} else {
	$layout = baroque_get_option( 'single_post_layout' );
}

if ( $layout == 'full-content' ) {
	$css_class = 'col-md-4 col-xs-12 col-sm-12';
} else {
	$css_class = 'col-md-6 col-xs-12 col-sm-12';
}

$numbers = intval( baroque_get_option( 'related_posts_numbers' ) );

$related_posts = new WP_Query(
	array(
		'posts_per_page'         => $numbers,
		'ignore_sticky_posts'    => 1,
		'category__in'           => wp_get_post_categories( get_the_ID() ),
		'post__not_in'           => array( get_the_ID() ),
		'no_found_rows'          => true,
		'update_post_term_cache' => false,
		'update_post_meta_cache' => false,
	)
);

$size      = 'baroque-blog-grid';
$col       = baroque_get_option( 'single_post_col' );
$offset    = baroque_get_option( 'single_post_col_offset' );
$colOffset = '';
if ( $offset != 0 ) {
	$colOffset = 'col-md-offset-' . $offset;
}

if ( ! $related_posts->have_posts() ) {
	return;
}

?>
	<div class="baroque-related-posts blog-grid">
		<div class="container">
			<div class="row">
				<div class="related-section-title col-md-<?php echo esc_attr( $col ) ?> <?php echo esc_attr( $colOffset ) ?> col-xs-12 col-sm-12">
					<?php
					if ( $titles = baroque_get_option( 'related_posts_title' ) ) {

						echo sprintf( '<h2 class="related-title">%s</h2>', esc_html( $titles ) );
					}
					?>
				</div>
			</div>
			<div class="list-post row">
				<?php while ( $related_posts->have_posts() ) : $related_posts->the_post(); ?>

					<article id="post-<?php the_ID(); ?>" <?php post_class( $css_class ); ?>>
						<div class="blog-wrapper">
							<?php if ( has_post_thumbnail() ) : ?>
								<div class="entry-thumbnail">
									<a class="blog-thumb" href="<?php the_permalink() ?>"><?php the_post_thumbnail( $size ) ?></a>
									<a href="<?php the_permalink() ?>" class="read-more">
										<?php echo apply_filters( 'baroque_related_post_read_more_text', esc_html__( 'MORE', 'baroque' ) ); ?>
										<i class="icon-plus"></i>
									</a>
								</div>
							<?php endif; ?>

							<div class="entry-summary">
								<div class="entry-header">
									<div class="entry-meta">
										<?php baroque_entry_meta() ?>
									</div><!-- .entry-meta -->
									<h2 class="entry-title"><a href="<?php the_permalink() ?>"><?php the_title(); ?></a>
									</h2>
								</div>
							</div><!-- .entry-content -->
						</div>
					</article><!-- #post-## -->

				<?php endwhile; ?>
			</div>
		</div>
	</div>

<?php
wp_reset_postdata();